@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
   code based on calligra autocorrection.
 
   SPDX-License-Identifier: GPL-2.0-or-later
@@ -44,9 +44,7 @@ AutoCorrection::AutoCorrection()
     }
 }
 
-AutoCorrection::~AutoCorrection()
-{
-}
+AutoCorrection::~AutoCorrection() = default;
 
 void AutoCorrection::selectStringOnMaximumSearchString(QTextCursor &cursor, int cursorPosition)
 {
@@ -451,7 +449,7 @@ void AutoCorrection::addNonBreakingSpace()
                 }
             }
         } else {
-            //°C (degres)
+            //°C (degrees)
             const int pos = mCursor.position() - 2 - block.position();
             if (pos >= 0) {
                 const QChar previousChar = text.at(pos);
@@ -666,7 +664,7 @@ QString AutoCorrection::autoDetectURL(const QString &_word) const
         return newWord;
     }
 
-    return QString();
+    return {};
 }
 
 void AutoCorrection::fixTwoUppercaseChars()
@@ -1031,7 +1029,8 @@ void AutoCorrection::readAutoCorrectionXmlFile(bool forceGlobal)
             kdelang = QStringLiteral("en_US");
         }
     }
-    kdelang.remove(QRegularExpression(QStringLiteral("@.*")));
+    static QRegularExpression reg(QStringLiteral("@.*"));
+    kdelang.remove(reg);
 
     mUpperCaseExceptions.clear();
     mAutocorrectEntries.clear();
@@ -1039,6 +1038,7 @@ void AutoCorrection::readAutoCorrectionXmlFile(bool forceGlobal)
     mSuperScriptEntries.clear();
 
     QString localFileName;
+    static QRegularExpression regpath(QRegularExpression(QStringLiteral("_.*")));
     // Look at local file:
     if (!forceGlobal) {
         if (!mAutoCorrectLang.isEmpty()) {
@@ -1050,7 +1050,7 @@ void AutoCorrection::readAutoCorrectionXmlFile(bool forceGlobal)
                     QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("autocorrect/custom-") + kdelang + QLatin1String(".xml"));
             }
             if (localFileName.isEmpty() && kdelang.contains(QLatin1Char('_'))) {
-                kdelang.remove(QRegularExpression(QStringLiteral("_.*")));
+                kdelang.remove(regpath);
                 localFileName =
                     QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("autocorrect/custom-") + kdelang + QLatin1String(".xml"));
             }
@@ -1069,7 +1069,7 @@ void AutoCorrection::readAutoCorrectionXmlFile(bool forceGlobal)
             fname = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("autocorrect/") + kdelang + QLatin1String(".xml"));
         }
         if (fname.isEmpty() && kdelang.contains(QLatin1Char('_'))) {
-            kdelang.remove(QRegularExpression(QStringLiteral("_.*")));
+            kdelang.remove(regpath);
             fname = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("autocorrect/") + kdelang + QLatin1String(".xml"));
         }
     }
